<!-- 一级弹框 -->
<template>
    <div element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <el-dialog :title="title" :visible="visible" :before-close="handleClose" :close-on-click-modal="false" width="80%"
            top="10vh">
            <div>
                <el-descriptions title="基础信息" border :column="3">
                    <el-descriptions-item label="项目名称">{{
                        parameter.projectName
                    }}</el-descriptions-item>
                    <el-descriptions-item label="责任单位">{{
                        parameter.unitName
                    }}</el-descriptions-item>
                    <el-descriptions-item label="专项小组">{{
                        parameter.groupName
                    }}</el-descriptions-item>
                    <el-descriptions-item label="牵头市领导">{{
                        parameter.leader
                    }}</el-descriptions-item>
                    <el-descriptions-item label="是否结项">{{
                        parameter.closing === 0 ? '已结项' : '未结项'
                    }}</el-descriptions-item>
                    <el-descriptions-item label="审核状态">
                        <template>
                            <status-by-color :status="parameter.status" />
                        </template>
                    </el-descriptions-item>
                    <el-descriptions-item label="提交时间">{{
                        parameter.thisTime
                    }}</el-descriptions-item>
                </el-descriptions>
                <div style="margin: 10px 0"></div>
                <el-table stripe size="mini" v-loading="loading" ref="multipleSelection"
                    :data="parameter.pilotSpecificMeasuresList" :max-height="300" :style="{ width: '100%' }"
                    @selection-change="handleSelectionChange">
                    <!-- <el-table-column type="selection" width="55" align="center"></el-table-column> -->
                    <el-table-column width="55" align="center">
                        <template v-slot="{ row, $index }">
                            <el-button type="text" @click="deleteList(row, $index)">
                                <i style="color: #f56c6c; font-size: 16px;font-weight: bold;" class="el-icon-delete"></i>
                            </el-button>
                        </template>
                    </el-table-column>
                    <el-table-column type="index" label="序号" align="center"></el-table-column>
                    <el-table-column prop="distributionType" show-overflow-tooltip label="原始举措" align="center">
                        <template slot-scope="scope">
                            {{
                                scope.row.rawMeasures || '----'
                            }}
                        </template>
                    </el-table-column>
                    <el-table-column prop="reformSpecificMeasures" show-overflow-tooltip label="具体举措" align="center">
                        <template slot-scope="scope">
                            {{
                                scope.row
                                    .reformSpecificMeasures
                            }}
                        </template>
                    </el-table-column>
                    <!-- <el-table-column
                        prop="distributionType"
                        show-overflow-tooltip
                        label="分发类型"
                        align="center"
                    >
                        <template slot-scope="scope">
                            {{
                                getDictName(
                                    'fflx',
                                    scope.row.pilotSpecificMeasures
                                        .distributionType
                                )
                            }}
                        </template>
                    </el-table-column> -->
                    <!-- <el-table-column prop="iteration" show-overflow-tooltip label="责任单位跌代类型" align="center">
						<template slot-scope="scope">
							{{getDictName('zrdwddlx', scope.row.iteration)}}
						</template>
					</el-table-column> -->
                    <el-table-column prop="status" show-overflow-tooltip label="审核状态" align="center">
                        <template slot-scope="scope">
                            <!-- {{
                                getDictName(
                                    'shzt',
                                    scope.row.status
                                )
                            }} -->
                            <status-by-color :status="scope.row.status" />
                        </template>
                    </el-table-column>
                    <el-table-column label="操作" align="center">
                        <template slot-scope="scope">
                            <el-link type="primary" :underline="false" class="cloumn-btn" @click="
                                handleDbClick(
                                    scope.row,
                                    scope.$index
                                )
                                ">
                                详情
                            </el-link>
                        </template>
                    </el-table-column>
                </el-table>
            </div>
            <span slot="footer" class="dialog-footer">
                <el-button v-if="title == '审核'" type="primary" @click="handleSave" :loading="saveLoading">通过</el-button>
                <el-button v-if="title == '审核'" type="danger" @click="handleReject" :loading="saveLoading">驳回</el-button>
                <el-button @click="handleClose">取消</el-button>
            </span>
        </el-dialog>
        <ActionDetailsDialog ref="ActionDetailsDialog" @getData="getData"></ActionDetailsDialog>
        <!-- 驳回填写意见弹层 -->
        <RejectInfoDialog ref="rejectInfoDialog" @sendRejectInfo="sendRejectInfo" />
    </div>
</template>

<script>
import moment from 'moment'
import org from '@/api/org.js'
import utils from '@/utils.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import measureIterationApplication from '@/api/projectActionIteration/measureIterationApplication.js'
import ActionDetailsDialog from './ActionDetailsDialog.vue'
import RejectInfoDialog from '@/components/dialog/RejectInfoBlockDialog.vue'
export default {
    name: 'ActionDialog',
    components: {
        ActionDetailsDialog,
        RejectInfoDialog,
    },
    data() {
        return {
            visible: false,
            title: '新增',
            loading: false,
            saveLoading: false,
            cancelloading: false,
            tableData: [],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
            },
            parameter: {},
            params: {
                ids: [],
                status: null,
            },
            statusValue: [],
            markLoading: false
        }
    },
    created() {
        // console.log(dictUtils.getDictItemsFromCache('shzt'))
    },
    mounted() { },
    methods: {
        deleteList(row, index) {
            this.$confirm('确认删除这条数据吗？', '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'error'
            }).then(() => {
                if (row.id) {
                    this.markLoading = true
                    measureIterationApplication.deleteAddById(row.id, true, res => {
                        if (res.state) {
                            this.$message.success('删除成功')
                            this.parameter.pilotSpecificMeasuresList.splice(index, 1)
                        }
                        this.markLoading = false
                    })
                } else {
                    this.parameter.pilotSpecificMeasuresList.splice(index, 1)
                }
            })
        },
        getData(val, index) {
            console.log(val, index)
            if (index >= 0) {
                this.$set(this.parameter.pilotSpecificMeasuresList, index, val)
            } else {
                this.parameter.pilotSpecificMeasuresList.push(val)
                this.$set(this.parameter)
            }
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        //表格选中
        handleSelectionChange(val) {
            this.multipleSelection = []
            this.$refs.multipleSelection.selection.forEach((item) => {
                this.multipleSelection.push(item.id)
            })
        },
        add(val, arr) {
            this.statusValue = arr
            this.parameter = JSON.parse(JSON.stringify(val))
            this.parameter.updateTime = moment(this.parameter.updateTime).format(
                'YYYY-MM-DD'
            )
            this.visible = true
            this.measureData()
        },
        //获取列表
        measureData() {
            this.loading = true
            // this.parameter.pilotSpecificMeasuresList = []
            this.queryParam.querys = [
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'h.project_id_',
                    relation: 'AND',
                    value: this.parameter.id,
                },
                {
                    group: 'statusGroup',
                    operation: 'IN',
                    parentGroup: '',
                    property: 'h.status_',
                    relation: 'AND',
                    value: this.statusValue,
                },
                {
                    group: 'statusGroup',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'h.SYN_STATUS_',
                    relation: 'AND',
                    value: this.title == '审核' ? -1 : '',
                },
            ]
            // measureIterationApplication.auditQuery(this.queryParam, (res) => {
            measureIterationApplication.gteAuditMeasuresDetail(this.queryParam, (res) => {
                if (res && res.rows && res.rows.length) {
                    // this.$set(
                    //     this.parameter,
                    //     'pilotSpecificMeasuresList',
                    //     res.rows
                    // )
                    this.parameter.pilotSpecificMeasuresList = res.rows
                }
                this.loading = false
            })
        },
        // 关闭新增人员窗口
        handleClose() {
            this.visible = false
            this.cancelloading = false
            this.saveLoading = false
            this.parameter = {}
            this.title = ''
        },
        //编辑
        handleDbClick(val) {
            this.$refs.ActionDetailsDialog.edit(val)
        },
        // 审核驳回意见
        handleReject() {
            this.saveLoading = true
            let status = 2
            let message = '确认驳回吗?'
            this.btnLoading = true
            this.$confirm(message, this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'error',
            })
                .then(() => {
                    this.$refs.rejectInfoDialog.open(
                        '/majorProjects/pilotSpecificMeasures/v1/iteration',
                        status
                    )
                })
                .catch(() => {
                    this.saveLoading = false
                })
        },
        // 处理填写的驳回意见
        sendRejectInfo(rejectInfo, api, status) {
            if (!rejectInfo) {
                this.saveLoading = false
                return
            }
            this.submit(rejectInfo)
            // let data = {
            //     approvalComments: rejectInfo,
            //     ids: this.projectInfo.id,
            //     status: status, //3-责任单位领导审核通过  5-市委改革办审核通过
            // }
            // measureIterationApplication.auditSave(this.params, (res) => {
            //     if (res.state) {
            //         this.$message.success('驳回成功')
            //         this.$parent.reload()
            //         this.handleClose()
            //     } else {
            //         this.$message.warning(res.message)
            //     }
            //     this.saveLoading = false
            // })
        },
        //驳回
        submit(approvalComments) {
            this.cancelloading = true
            this.params.ids = []
            this.parameter.pilotSpecificMeasuresList.forEach((e) => {
                this.params.ids.push(e.id)
            })
            this.params.status = this.$route.name == 'IterativeValidationAction' ? 4 : 2
            if (this.params.ids.length <= 0) {
                this.$message.warning('暂无可驳回数据')
                this.cancelloading = false
                return
            }
            this.params.approvalComments = approvalComments
            measureIterationApplication.auditSave(this.params, (res) => {
                if (res.state) {
                    this.$message.success('驳回成功')
                    this.cancelloading = false
                    this.$emit('getData')
                    this.handleClose()
                }
                this.saveLoading = false
            })
        },
        // 通过
        handleSave(row) {
            this.saveLoading = true
            this.params.ids = []
            this.parameter.pilotSpecificMeasuresList.forEach((e) => {
                this.params.ids.push(e.id)
            })
            this.params.status = this.$route.name == 'IterativeValidationAction' ? 5 : 3
            if (this.params.ids.length <= 0) {
                this.$message.warning('暂无可审核数据')
                this.saveLoading = false
                return
            }
            measureIterationApplication.auditSave(this.params, (res) => {
                if (res.state) {
                    row.status = 3
                    this.$message.success('审核成功')

                    this.$emit('getData')
                    this.handleClose()
                }
                this.saveLoading = false
            })
        },
    },
}
</script>

<style lang="scss" scoped>
@import "~@/assets/css/element-variables.scss";

.add-btn {
    font-weight: bold;
    cursor: pointer;
    color: $--color-primary;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/.el-dialog__body {
    max-height: 600px;
    overflow-y: auto;

}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}
</style>
